# Basic Algorithms


## 1. Quick Sort
Quick Sort is a sorting algorithm, which is commonly used in computer science. 
Quick Sort is a divide and conquer algorithm. 

### Usage
```python
from data_structure import quickSort

print(quickSort([8, 12, 55, -12]))
```

### Output
```bash
[-12, 8, 12, 55]
```